@@ -16,7 +16,7 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core.client_options import ClientOptions
@@ -216,14 +216,13 @@ class AssetServiceAsyncClient:
         cloud.assets.SearchAllResources permission on the
         requested scope, otherwise it will be rejected.
 
-
         .. code-block:: python
 
             from google.cloud import asset_v1p1beta1
 
-            def sample_search_all_resources():
+            async def sample_search_all_resources():
                 # Create a client
-                client = asset_v1p1beta1.AssetServiceClient()
+                client = asset_v1p1beta1.AssetServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = asset_v1p1beta1.SearchAllResourcesRequest(
@@ -234,7 +233,7 @@ class AssetServiceAsyncClient:
                 page_result = client.search_all_resources(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -327,12 +326,20 @@ class AssetServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.SearchAllResourcesAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -357,14 +364,13 @@ class AssetServiceAsyncClient:
         cloud.assets.SearchAllIamPolicies permission on the
         requested scope, otherwise it will be rejected.
 
-
         .. code-block:: python
 
             from google.cloud import asset_v1p1beta1
 
-            def sample_search_all_iam_policies():
+            async def sample_search_all_iam_policies():
                 # Create a client
-                client = asset_v1p1beta1.AssetServiceClient()
+                client = asset_v1p1beta1.AssetServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = asset_v1p1beta1.SearchAllIamPoliciesRequest(
@@ -375,7 +381,7 @@ class AssetServiceAsyncClient:
                 page_result = client.search_all_iam_policies(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -461,12 +467,20 @@ class AssetServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.SearchAllIamPoliciesAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -481,7 +495,9 @@ class AssetServiceAsyncClient:
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution("google-cloud-asset",).version,
+        gapic_version=pkg_resources.get_distribution(
+            "google-cloud-asset",
+        ).version,
     )
 except pkg_resources.DistributionNotFound:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
